/*
 *  Copyright 2008 Olivier PARISOT
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.doopyon.musaterm.javame;

import javax.microedition.lcdui.*;

import org.doopyon.musaterm.javame.term.*;


/**
 * Terminal for Java ME.
 * 
 * @author Olivier PARISOT
 */
public final class MicroTerminal extends Terminal 
{
	//
	// Static fields
	//

	/** Terminal name. */
	private static final String TERMINAL_NAME="musaterm-me";
	
	/** Splash message. */
	private static final String SPLASH_MESSAGE="Welcome to the "+TERMINAL_NAME+".\n\n";
	  
	/** Prompt message. */
	private static final String PROMPT_MESSAGE="you@"+TERMINAL_NAME+"> ";

	/** End message. */
	private static final String END_MESSAGE="This terminal is closed!\n";	
	
	/** */
	private static final javax.microedition.lcdui.Command EXECUTE_COMMAND=new javax.microedition.lcdui.Command("Execute",javax.microedition.lcdui.Command.OK,1);
	
	
	//
	// Instance fields
	//
	
    /** The working form. */
    private Form form;
    /** The working textfield. */
    private TextField tf;
    /** */
    private boolean closed;
    
	
	//
	// Constructor
	//
	
    /**
     * Constructor.
     */
	public MicroTerminal(AbstractCommandLineExecutor commandManager,Display display) 
	{
		super(commandManager);
		display.setCurrent(this.form=new Form(TERMINAL_NAME));
		this.form.addCommand(EXECUTE_COMMAND);
		this.form.setCommandListener(new MicroTerminalListener());
	}
	
	
	//
	// Instance methods
	//
	
	/**
	 * {@inheritDoc} 
	 */
	public void clear() 
	{
		form.deleteAll();
		print(SPLASH_MESSAGE);		
	}

	/**
	 * {@inheritDoc} 	
	 */ 
	public void init() 
	{
		print(SPLASH_MESSAGE);
		printNewPrompt();		
	}

	/**
	 * {@inheritDoc} 
	 */
	public void close()
	{
		super.close();
		print(END_MESSAGE);
		closed=true;
	}	
	
	/**
	 * {@inheritDoc} 
	 */	
	public void print(String text)
	{
		form.append(text);
	}

	/**
	 * Print a new prompt on the terminal.
	 */
	private void printNewPrompt()
	{
		print(PROMPT_MESSAGE);		
		form.append(tf=new TextField("","",20,TextField.ANY));		
	}
	
	
	//
	// Private classes
	//
		
	/**
	 * Terminal listener.
	 * 
	 * @author Olivier PARISOT
	 */
	private final class MicroTerminalListener implements CommandListener
	{
		//
		// Instance methods
		//
		
		/**
		 * {@inheritDoc}
		 */
		public void commandAction(javax.microedition.lcdui.Command command,Displayable displayable) 
		{
			if (command.equals(EXECUTE_COMMAND))
			{				
				executeCommandLine(tf.getString());
				if (!closed) printNewPrompt();					
			}
			else
			{
				throw new IllegalStateException();
			}
		}
		
	}

}
