/*
 *  Copyright 2008 Olivier PARISOT
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.doopyon.musaterm.javame.term;


/**
 * Definition of a terminal.
 *
 * @author Olivier PARISOT
 */
public interface AbstractTerminal 
{
	//
	// Instance methods
	//
	
	/**
	 * Init the terminal.
	 */
	void init();	
	
	/**
	 * Clear the terminal output.
	 */
	void clear();
	
	/**
	 * Print a text on the terminal output.
	 * @param text
	 */
	void print(String text);
	
	/**
	 * Execute a command line.
	 * @param commandLine
	 */
	void executeCommandLine(String commandLine);
	
	/**
	 * Close the terminal.
	 */
	void close();
	
	/**
	 * Check if the terminal is closed.
	 */
	boolean isClosed();
}
