/*
 *  Copyright 2008 Olivier PARISOT
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.doopyon.musaterm.javame.term;


/**
 * Command processor.
 *
 * @author Olivier PARISOT
 */
public final class CommandLineExecutor implements AbstractCommandLineExecutor
{
	//
	// Instance fields
	//
	
	/** The working command line parser. */
	private final AbstractCommandLineParser parser;
	
	
	//
	// Constructor
	//
	
	/**
	 * Constructor.
	 */
	public CommandLineExecutor(AbstractCommandsProvider provider)
	{
		this(new CommandLineParser(provider));
	}

	/**
	 * Constructor.
	 */
	public CommandLineExecutor(AbstractCommandLineParser parser)
	{
		this.parser=parser;
	}
	
	
	//
	// Instance methods
	//
  
	/**
	 * {@inheritDoc}
   	 */
	public void executeCommandLine(String commandLine,Terminal terminal)
	{
		try
		{
			final Command c=parser.parseCommand(commandLine);
			if (c==null) throw new MissingCommandException();
			final ArgumentsList a=parser.parseArgument(commandLine);
			c.execute(a,terminal);
		}
		catch(Exception e)
		{
			terminal.print("Error when executing the command line '"+commandLine+"': "+e.getMessage());
		}
	}
}