/*
 *  Copyright 2008 Olivier PARISOT
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.doopyon.musaterm.javame.term;


/**
 * Terminal.
 *
 * @author Olivier PARISOT
 */
public abstract class Terminal implements AbstractTerminal
{
	//
	// Instance fields
	//
	
	/** The working command processor. */
	private final AbstractCommandLineExecutor executor; 	
	
	/** */
	private boolean closed=false;
	
	
	//
	// Constructor
	//
	
	/**
	 * Constructor.
	 */
	public Terminal(AbstractCommandLineExecutor executor)
	{
		this.executor=executor;		
	}
		
	//
	// Instance methods
	//
	
	/**
	 * {@inheritDoc}
	 */
	public final void executeCommandLine(String commandLine)
	{
		executor.executeCommandLine(commandLine,this);
	}
	
	/**
	 * {@inheritDoc}
	 */
	public void close()
	{
		this.closed=true;
	}
	
	/**
	 * {@inheritDoc}
	 */
	public final boolean isClosed()
	{
		return closed;
	}	
}
