/*
 *  Copyright 2008 Olivier PARISOT
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.doopyon.musaterm.javame.term.common;

import org.doopyon.musaterm.javame.term.*;
import j2me.util.*;


/**
 * Help command.
 * 
 * @author Olivier PARISOT
 */
final class HelpCommand extends Command
{
	//
	// Static fields
	//
	
	/** Command name. */
	private static final String NAME="help";
	/** Help. */
	private static final String HELP="provide the help!";
	
	
	//
	// Instance fields
	//
	
	/** The list of commands for which help should be provided. */
	private List commands;
	
	
	//
	// Constructor
	//
	
	/**
	 * Constructor.
	 */
	HelpCommand(List commands)
	{
		if (commands==null) throw new IllegalArgumentException();
		this.commands=commands;
	}
	
	//
	// Instance methods
	//
	
	/**
	 * {@inheritDoc}
	 */
	public String getName()
	{
		return NAME;
	}
	
	/**
	 * {@inheritDoc}
	 */
	public void execute(ArgumentsList argument,AbstractTerminal terminal)
	{
		final StringBuffer sb=new StringBuffer();
		sb.append("\nHere is the list of the available commands:\n");
		for (Iterator iter=commands.iterator();iter.hasNext();)
		{ 
			final Command command=(Command)iter.next();
			if (command.isHelpProvided())
			{
				sb.append(" - ")
				  .append(command.getName())
				  .append(": ")
				  .append(command.getHelp())
				  .append("\n");
			}
		}
		sb.append("\n");
		terminal.print(sb.toString());
	}
	
	/**
	 * {@inheritDoc}
	 */
	public String getHelp()
	{
		return HELP;
	}			
}
